@@ -679,7 +679,7 @@
 
 mmlt <- function(..., formula = ~ 1, data, conditional = FALSE, 
                  theta = NULL, fixed = NULL, scale = FALSE,
-                 optim = mltoptim(auglag = list(maxtry = 5)),  ### provides hessian
+                 optim = mltoptim(hessian = TRUE),  ### provides hessian
                  args = list(seed = 1, M = 1000), 
                  dofit = TRUE, domargins = TRUE)
 {
